#########
 Weights
#########

The `weights` are a node attribute useful for defining the importance of
a node in the loss function. You can set the weights to follow an
uniform distribution or to match the area associated with that node.

.. literalinclude:: ../yaml/attributes_weights.yaml
   :language: yaml
